merge ca config and client config, remove old format of probe

Change-Id: I73500f532f166851d82c1bf1cc008c7ffc241ef3
diff --git a/src/client-module.hpp b/src/client-module.hpp
index c439d3c..fd88129 100644
--- a/src/client-module.hpp
+++ b/src/client-module.hpp
@@ -21,7 +21,7 @@
 #ifndef NDNCERT_CLIENT_MODULE_HPP
 #define NDNCERT_CLIENT_MODULE_HPP
 
-#include "client-config.hpp"
+#include "configuration.hpp"
 #include "request-state.hpp"
 #include "crypto-support/crypto-helper.hpp"
 
@@ -30,7 +30,7 @@
 
 // TODO
 // For each CA item in Client.Conf, create a validator instance and initialize it with CA's cert
 // The validator instance should be in ClientCaItem
 
 class ClientModule : noncopyable
 {
@@ -83,7 +83,7 @@
   addCaFromInfoResponse(const Data& reply);
 
   shared_ptr<Interest>
-  generateProbeInterest(const ClientCaItem& ca, const std::string& probeInfo);
+  generateProbeInterest(const CaConfigItem& ca, std::vector<std::tuple<std::string, std::string>>&& probeInfo);
 
   void
   onProbeResponse(const Data& reply);
@@ -114,9 +114,6 @@
   void
   onCertFetchResponse(const Data& reply);
 
-  static std::vector<std::string>
-  parseProbeComponents(const std::string& probe);
-
   void
   endSession();
 
@@ -124,7 +121,7 @@
   ClientConfig m_config;
   security::v2::KeyChain& m_keyChain;
 
-  ClientCaItem m_ca;
+  CaConfigItem m_ca;
   security::Key m_key;
   Name m_identityName;
 
@@ -132,7 +129,6 @@
   Status m_status = Status::NOT_STARTED;
   std::string m_challengeStatus = "";
   std::string m_challengeType = "";
-  std::string m_certId = "";
   Name m_issuedCertName;
   std::list<std::string> m_challengeList;
   bool m_isCertInstalled = false;
@@ -30,7 +30,7 @@
 // TODO
 // For each CA item in Client.Conf, create a validator instance and initialize it with CA's cert
-// The validator instance should be in ClientCaItem
+// The validator instance should be in CaConfigItem
 
 class ClientModule : noncopyable